@@ -3,9 +3,9 @@ use clap::Parser;
 
 use cmd::meta::Kubie;
 use settings::Settings;
+use skim::prelude::SkimOptionsBuilder;
 
 mod cmd;
-mod fzf;
 mod ioutil;
 mod kubeconfig;
 mod kubectl;
@@ -17,6 +17,7 @@ mod vars;
 
 fn main() -> Result<()> {
     let settings = Settings::load()?;
+    let skim_options = SkimOptionsBuilder::default().multi(false).build().unwrap();
     let kubie = Kubie::parse();
 
     match kubie {
@@ -26,14 +27,21 @@ fn main() -> Result<()> {
             kubeconfigs,
             recursive,
         } => {
-            cmd::context::context(&settings, context_name, namespace_name, kubeconfigs, recursive)?;
+            cmd::context::context(
+                &settings,
+                &skim_options,
+                context_name,
+                namespace_name,
+                kubeconfigs,
+                recursive,
+            )?;
         }
         Kubie::Namespace {
             namespace_name,
             recursive,
             unset,
         } => {
-            cmd::namespace::namespace(&settings, namespace_name, recursive, unset)?;
+            cmd::namespace::namespace(&settings, &skim_options, namespace_name, recursive, unset)?;
         }
         Kubie::Info(info) => {
             cmd::info::info(info)?;
@@ -58,7 +66,7 @@ fn main() -> Result<()> {
             cmd::lint::lint(&settings)?;
         }
         Kubie::Edit { context_name } => {
-            cmd::edit::edit_context(&settings, context_name)?;
+            cmd::edit::edit_context(&settings, &skim_options, context_name)?;
         }
         Kubie::EditConfig => {
             cmd::edit::edit_config()?;
@@ -67,7 +75,7 @@ fn main() -> Result<()> {
             cmd::update::update()?;
         }
         Kubie::Delete { context_name } => {
-            cmd::delete::delete_context(&settings, context_name)?;
+            cmd::delete::delete_context(&settings, &skim_options, context_name)?;
         }
     }
 
